@@ -1,17 +1,14 @@
-from __future__ import unicode_literals
-
 import logging
 
 from pydbus.generic import signal
 
-
 logger = logging.getLogger(__name__)
 
 # This should be kept in sync with mopidy.internal.log.TRACE_LOG_LEVEL
 TRACE_LOG_LEVEL = 5
 
 
-class Interface(object):
+class Interface:
     def __init__(self, config, core):
         self.config = config
         self.core = core
