@@ -1,16 +1,14 @@
-from mopidy.core import Core
-
 import pytest
 
+from mopidy.core import Core
+
 from tests import dummy_audio, dummy_backend, dummy_mixer
 
 
 @pytest.fixture
 def config():
     return {
-        'core': {
-            'max_tracklist_length': 10000,
-        },
+        "core": {"max_tracklist_length": 10000},
     }
 
 
