@@ -4,22 +4,20 @@ This backend implements the backend API in the simplest way possible.  It is
 used in tests of the frontends.
 """
 
-from __future__ import absolute_import, unicode_literals
+
+import pykka
 
 from mopidy import backend
 from mopidy.models import Playlist, Ref, SearchResult
 
-import pykka
-
 
 def create_proxy(config=None, audio=None):
     return DummyBackend.start(config=config, audio=audio).proxy()
 
 
 class DummyBackend(pykka.ThreadingActor, backend.Backend):
-
     def __init__(self, config, audio):
-        super(DummyBackend, self).__init__()
+        super().__init__()
 
         self.library = DummyLibraryProvider(backend=self)
         if audio:
@@ -28,14 +26,14 @@ class DummyBackend(pykka.ThreadingActor, backend.Backend):
             self.playback = DummyPlaybackProvider(audio=audio, backend=self)
         self.playlists = DummyPlaylistsProvider(backend=self)
 
-        self.uri_schemes = ['dummy']
+        self.uri_schemes = ["dummy"]
 
 
 class DummyLibraryProvider(backend.LibraryProvider):
-    root_directory = Ref.directory(uri='dummy:/', name='dummy')
+    root_directory = Ref.directory(uri="dummy:/", name="dummy")
 
     def __init__(self, *args, **kwargs):
-        super(DummyLibraryProvider, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.dummy_library = []
         self.dummy_get_distinct_result = {}
         self.dummy_get_images_result = {}
@@ -65,9 +63,8 @@ class DummyLibraryProvider(backend.LibraryProvider):
 
 
 class DummyPlaybackProvider(backend.PlaybackProvider):
-
     def __init__(self, *args, **kwargs):
-        super(DummyPlaybackProvider, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._uri = None
         self._time_position = 0
 
@@ -75,7 +72,7 @@ class DummyPlaybackProvider(backend.PlaybackProvider):
         return True
 
     def play(self):
-        return self._uri and self._uri != 'dummy:error'
+        return self._uri and self._uri != "dummy:error"
 
     def change_track(self, track):
         """Pass a track with URI 'dummy:error' to force failure"""
@@ -102,9 +99,8 @@ class DummyPlaybackProvider(backend.PlaybackProvider):
 
 
 class DummyPlaylistsProvider(backend.PlaylistsProvider):
-
     def __init__(self, backend):
-        super(DummyPlaylistsProvider, self).__init__(backend)
+        super().__init__(backend)
         self._playlists = []
 
     def set_dummy_playlists(self, playlists):
@@ -113,14 +109,14 @@ class DummyPlaylistsProvider(backend.PlaylistsProvider):
 
     def as_list(self):
         return [
-            Ref.playlist(uri=pl.uri, name=pl.name) for pl in self._playlists]
+            Ref.playlist(uri=pl.uri, name=pl.name) for pl in self._playlists
+        ]
 
     def get_items(self, uri):
         playlist = self.lookup(uri)
         if playlist is None:
             return
-        return [
-            Ref.track(uri=t.uri, name=t.name) for t in playlist.tracks]
+        return [Ref.track(uri=t.uri, name=t.name) for t in playlist.tracks]
 
     def lookup(self, uri):
         for playlist in self._playlists:
@@ -131,7 +127,7 @@ class DummyPlaylistsProvider(backend.PlaylistsProvider):
         pass
 
     def create(self, name):
-        playlist = Playlist(name=name, uri='dummy:%s' % name)
+        playlist = Playlist(name=name, uri="dummy:%s" % name)
         self._playlists.append(playlist)
         return playlist
 
